// AUTO-GENERATED BY UpdateGenVersion.bat e5bf0f9adc1bbb460cb7079cdacb4499f1a00a04
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "e5bf0f9adc1bbb460cb7079cdacb4499f1a00a04";
